==> currents-api-types-0.0.77.tgz: package/paymentMethod/parsers.ts <==
import { z } from 'zod';
import { PAYMENT_METHOD_ORIGIN_ID_PARAM_NAME, PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME } from './routes.constant';
import { stripePaymentMethodIdParser } from '../stripe/parsers';
import { makeLimitParser, queryLimitParser } from '../common/parsers/queryParams';

export const stripePamentMethodOriginIdParser = z.object({
  [PAYMENT_METHOD_ORIGIN_ID_PARAM_NAME]: stripePaymentMethodIdParser,
  [PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME]: z.literal('stripe'),
});
export const paypalPaymentMethodOriginIdParser = z.object({
  [PAYMENT_METHOD_ORIGIN_ID_PARAM_NAME]: z.string(), // TODO
  [PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME]: z.literal('paypal'),
});

// TODO may become different for payin/payout if origins become different
export const paymentMethodCompositeKeyParamsParser = z.discriminatedUnion(PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME, [
  stripePamentMethodOriginIdParser,
  paypalPaymentMethodOriginIdParser,
]);
export const paymentMethodLimitParser = queryLimitParser.superRefine((a, ctx) => {
  if (a < 0) {
    ctx.addIssue({
      code: z.ZodIssueCode.too_small,
      message: 'Limit must be positive',
      minimum: 0,
      inclusive: true,
      type: 'number',
    });
  }
  const MAX = 100; /*stripe max, don't expose stripe related stuff here tho*/
  if (a > MAX) {
    ctx.addIssue({
      code: z.ZodIssueCode.too_big,
      message: `Limit must be less than ${MAX}`,
      maximum: MAX,
      inclusive: true,
      type: 'number',
    });
  }
  return a;
});

export const paymentMethodListLimitParser = makeLimitParser(paymentMethodLimitParser);

==> currents-api-types-0.0.90.tgz: package/paymentMethod/parsers.ts <==
import { z } from 'zod';
import { PAYMENT_METHOD_ORIGIN_ID_PARAM_NAME, PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME } from './routes.constant';
import { stripePaymentMethodIdParser } from '../stripe/parsers';
import { makeLimitParser, queryLimitParser } from '../common/parsers/queryParams';
import { paypalPayoutMethodIdParser } from '../paypal/parsers';

// TODO no payment. payin/payout
export const stripePamentMethodOriginIdParser = z.object({
  [PAYMENT_METHOD_ORIGIN_ID_PARAM_NAME]: stripePaymentMethodIdParser,
  [PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME]: z.literal('stripe'),
});

// TODO no payment. payin/payout
export const paypalPaymentMethodOriginIdParser = z.object({
  [PAYMENT_METHOD_ORIGIN_ID_PARAM_NAME]: paypalPayoutMethodIdParser,
  [PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME]: z.literal('paypal'),
});

// TODO no payment. payin/payout
export const paymentMethodCompositeKeyParamsParser = z.discriminatedUnion(PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME, [
  stripePamentMethodOriginIdParser,
  paypalPaymentMethodOriginIdParser,
]);
export const paymentMethodLimitParser = queryLimitParser.superRefine((a, ctx) => {
  if (a < 0) {
    ctx.addIssue({
      code: z.ZodIssueCode.too_small,
      message: 'Limit must be positive',
      minimum: 0,
      inclusive: true,
      type: 'number',
    });
  }
  const MAX = 100; /*stripe max, don't expose stripe related stuff here tho*/
  if (a > MAX) {
    ctx.addIssue({
      code: z.ZodIssueCode.too_big,
      message: `Limit must be less than ${MAX}`,
      maximum: MAX,
      inclusive: true,
      type: 'number',
    });
  }
  return a;
});

export const paymentMethodListLimitParser = makeLimitParser(paymentMethodLimitParser);
